@@ -195,7 +195,7 @@ Value::Value()
 :
   Glib::ValueBase()
 {
-  //Creates a null. TODO: Is this really equivalent to gda_value_new_null()?
+  init(gda_value_new_null());
 }
 
 Value::Value(const Value& src)
@@ -216,10 +216,20 @@ Value::Value(const GValue* castitem)
 
 Value& Value::operator=(const Value& src)
 {
+  if(this == &src)
+    return *this;
+
+  //Avoid doing anything if no change is necessary:
+  if(gobj() == src.gobj())
+    return *this;
+
   // Unset current value, if any
-  if(G_IS_VALUE(gobj())) g_value_unset(gobj());
+  if(G_IS_VALUE(gobj()))
+    g_value_unset(gobj());
+
   // Set new value, if any
-  if(G_IS_VALUE(src.gobj())) init(src.gobj());
+  if(G_IS_VALUE(src.gobj()))
+    init(src.gobj());
 
   return *this;
 }
@@ -242,6 +252,11 @@ bool Value::is_null() const
   return gda_value_is_null(const_cast<GValue*>(gobj()));
 }
 
+void Value::set_null()
+{
+  gda_value_set_null( gobj() );
+}
+
 bool Value::is_number() const
 {
   return gda_value_is_number(const_cast<GValue*>(gobj()));
@@ -284,6 +299,8 @@ const guchar* Value::get_binary(long& size) const
 
 void Value::set(const guchar* val, long size)
 {
+  value_reinit(gobj(), GDA_TYPE_BINARY);
+  
   GdaBinary gdabinary;
   gdabinary.data = const_cast<guchar*>(val);
   gdabinary.binary_length = size;
